@@ -1,5 +1,16 @@
 
-# $rcs = ' $Id: Charset.pm,v 1.375 2004/10/24 18:03:22 Daddy Exp $ ' ;
+# $rcs = ' $Id: Charset.pm,v 1.379 2005/09/02 21:32:04 Daddy Exp $ ' ;
+
+package I18N::Charset;
+
+require 5.002;
+
+require Exporter;
+use Carp;
+use IO::String;
+
+# Don't leave home without it:
+use strict;
 
 =head1 NAME
 
@@ -29,16 +40,6 @@ I18N::Charset - IANA Character Set Registry names and Unicode::MapUTF8
   I18N::Charset::add_libi_alias('my-sjis' => 'x-sjis');
   I18N::Charset::add_enco_alias('my-japanese' => 'shiftjis');
 
-=cut
-
-#-----------------------------------------------------------------------
-
-package I18N::Charset;
-
-require 5.002;
-
-#-----------------------------------------------------------------------
-
 =head1 DESCRIPTION
 
 The C<I18N::Charset> module provides access to the IANA Character Set
@@ -63,20 +64,11 @@ functions will always return undef.
 
 =cut
 
-#-----------------------------------------------------------------------
-
-require Exporter;
-use Carp;
-use IO::String;
-
-# Don't leave home without it:
-use strict;
-
 #-----------------------------------------------------------------------
 #	Public Global Variables
 #-----------------------------------------------------------------------
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK );
-$VERSION = do { my @r = (q$Revision: 1.375 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.379 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 @ISA       = qw( Exporter );
 @EXPORT    = qw( iana_charset_name
 map8_charset_name
@@ -94,14 +86,14 @@ mib_to_charset_name charset_name_to_mib
 #	Private Global Variables
 #-----------------------------------------------------------------------
 
-# %SHORTtoMIB is a hash of stripped names to mib.
-my %SHORTtoMIB;
-# %MIBtoLONG is a hash of mib to long name.
-my %MIBtoLONG;
-# %LONGtoMIB is a hash of long name to mib.
-my %LONGtoMIB;
-# %MIBtoMIME is a hash of mib to preferred MIME names.
-my %MIBtoMIME;
+# %hsMIBofShortname is a hash of stripped names to mib.
+my %hsMIBofShortname;
+# %hsLongnameOfMIB is a hash of mib to long name.
+my %hsLongnameOfMIB;
+# %hsMIBofLongname is a hash of long name to mib.
+my %hsMIBofLongname;
+# %hsMIMEofMIB is a hash of mib to preferred MIME names.
+my %hsMIMEofMIB;
 # %MIBtoMAP8 is a hash of mib to Unicode::Map8 names.  (Only valid for
 # those U::Map8 names that we can find in the IANA registry)
 my %MIBtoMAP8;
@@ -165,7 +157,7 @@ sub iana_charset_name
   # Make sure this is really a IANA mib:
   return undef if &_is_dummy($mib);
   # print STDERR " + is really iana..." if $iDebug;
-  return $MIBtoLONG{$mib};
+  return $hsLongnameOfMIB{$mib};
   } # iana_charset_name
 
 
@@ -186,7 +178,7 @@ sub _short_to_mib
  TRY_SHORT:
   foreach my $sTry (&_try_list($code))
     {
-    my $iMIB = $SHORTtoMIB{$sTry} || 'undef';
+    my $iMIB = $hsMIBofShortname{$sTry} || 'undef';
     # print STDERR "try($sTry)...$iMIB..." if DEBUG;
     if ($iMIB ne 'undef')
       {
@@ -204,7 +196,7 @@ sub _short_to_long
   local $^W = 0;
   my $s = shift;
   # print STDERR " + _short_to_long($s)..." if DEBUG;
-  return $MIBtoLONG{&_short_to_mib($s)};
+  return $hsLongnameOfMIB{&_short_to_mib($s)};
   } # _short_to_long
 
 
@@ -233,7 +225,7 @@ sub mime_charset_name
   # Make sure this is really an IANA mib:
   return undef if &_is_dummy($mib);
   # print STDERR " + is really iana..." if DEBUG;
-  return $MIBtoMIME{$mib};
+  return $hsMIMEofMIB{$mib};
   } # mime_charset_name
 
 
@@ -283,7 +275,7 @@ sub _maybe_load_enco # PRIVATE
       # At this point we have a mib for this Encode entry.
       $MIBtoENCO{$mib} = $s;
       DEBUG_ENCO && print STDERR " +   mib for enco ==$s== is $mib\n";
-      $SHORTtoMIB{&_strip($s)} = $mib;
+      $hsMIBofShortname{&_strip($s)} = $mib;
       DEBUG_ENCO && print STDERR " +   assign enco =$s==>$mib\n" if &_is_dummy($mib);
       } # foreach ENCODING
     if (DEBUG_ENCO)
@@ -381,7 +373,7 @@ sub _maybe_load_libi # PRIVATE
           {
           $MIBtoLIBI{$mib} = $sWord;
           # print STDERR " +   mib for libi ==$sWord== is $mib\n";
-          $SHORTtoMIB{&_strip($sWord)} = $mib;
+          $hsMIBofShortname{&_strip($sWord)} = $mib;
           } # foreach ADD_LIBI
         } # foreach ICONV_LINE
       } # if
@@ -433,7 +425,7 @@ sub mib_to_charset_name
   return undef unless defined $code;
   return undef unless $code ne '';
   local $^W = 0;
-  return $MIBtoLONG{$code};
+  return $hsLongnameOfMIB{$code};
   } # mib_to_charset_name
 
 
@@ -454,7 +446,7 @@ sub charset_name_to_mib
   {
   my $s = shift;
   return undef unless defined($s);
-  return $LONGtoMIB{$s} || $LONGtoMIB{
+  return $hsMIBofLongname{$s} || $hsMIBofLongname{
                                       &iana_charset_name($s) ||
                                       &umap_charset_name($s) ||
                                       &map8_charset_name($s) ||
@@ -580,7 +572,7 @@ The names are not in any particular order.
 
 sub all_iana_charset_names
   {
-  return values %MIBtoLONG;
+  return values %hsLongnameOfMIB;
   } # all_iana_charset_names
 
 #-----------------------------------------------------------------------
@@ -628,7 +620,7 @@ sub add_iana_alias
     } # if
   my $mib = &_short_to_mib(&_strip($sName));
   # print STDERR " --> $sName --> $mib\n";
-  $SHORTtoMIB{&_strip($sAlias)} = $mib;
+  $hsMIBofShortname{&_strip($sAlias)} = $mib;
   return $sName;
   } # add_iana_alias
 
@@ -681,9 +673,9 @@ sub add_map8_alias
     carp qq{attempt to alias "$sAlias" to unknown Map8 charset "$sReal"};
     return undef;
     } # if
-  if (exists $SHORTtoMIB{$sShortName})
+  if (exists $hsMIBofShortname{$sShortName})
     {
-    $SHORTtoMIB{$sShort} = $SHORTtoMIB{$sShortName};
+    $hsMIBofShortname{$sShort} = $hsMIBofShortname{$sShortName};
     } # if
   return $sName;
   } # add_map8_alias
@@ -708,9 +700,9 @@ sub add_umap_alias
     carp qq{attempt to alias "$sAlias" to unknown U::Map charset "$sReal"};
     return undef;
     } # if
-  if (exists $SHORTtoMIB{$sShortName})
+  if (exists $hsMIBofShortname{$sShortName})
     {
-    $SHORTtoMIB{$sShort} = $SHORTtoMIB{$sShortName};
+    $hsMIBofShortname{$sShort} = $hsMIBofShortname{$sShortName};
     } # if
   return $sName;
   } # add_umap_alias
@@ -754,7 +746,7 @@ sub add_libi_alias
     } # if
   my $mib = &_short_to_mib(&_strip($sName));
   # print STDERR "sName=$sName...mib=$mib\n";
-  $SHORTtoMIB{&_strip($sAlias)} = $mib;
+  $hsMIBofShortname{&_strip($sAlias)} = $mib;
   return $sName;
   } # add_libi_alias
 
@@ -798,7 +790,7 @@ sub add_enco_alias
     } # if
   my $mib = &_short_to_mib(&_strip($sName));
   print STDERR "sName=$sName...mib=$mib\n" if ($iDebug || DEBUG_ENCO);
-  $SHORTtoMIB{&_strip($sAlias)} = $mib;
+  $hsMIBofShortname{&_strip($sAlias)} = $mib;
   return $sName;
   } # add_enco_alias
 
@@ -891,7 +883,9 @@ while (1)
   my ($sName, $iMIB, $sAlias, $mimename);
   my $iDebug = 0;
   # I used to use the __DATA__ mechanism to initialize the data, but
-  # that is not compatible with perlapp
+  # that is not compatible with perlapp.  NOTE that storing the IANA
+  # charset data as a file separate from this module code will not
+  # work with perlapp either!
   my $io = new IO::String(_init_data());
   local $/ = "\n";
  DATA:
@@ -920,13 +914,13 @@ while (1)
       $iMIB = $1;
       # $iDebug = ($iMIB =~ m!225[23]!);
       print STDERR " +   found mib: $iMIB, long = $sName\n" if $iDebug;
-      $MIBtoLONG{$iMIB} = $sName;
-      $LONGtoMIB{$sName} = $iMIB;
-      $SHORTtoMIB{&_strip($sName)} = $iMIB;
+      $hsLongnameOfMIB{$iMIB} = $sName;
+      $hsMIBofLongname{$sName} = $iMIB;
+      $hsMIBofShortname{&_strip($sName)} = $iMIB;
       if ($mimename)
         {
         print STDERR " +   found mime: mib=$iMIB, mime=$sName\n" if $iDebug;
-	$MIBtoMIME{$iMIB} = $sName;
+	$hsMIMEofMIB{$iMIB} = $sName;
         # We've got the MIME name for this entry, don't look for more
         # until next entry:
         $mimename = 0;
@@ -938,11 +932,11 @@ while (1)
       if ($sAlias !~ m!None!i)
         {
         print STDERR " +   map Alias ($sAlias) to mib $iMIB\n" if $iDebug;
-        $SHORTtoMIB{&_strip($sAlias)} = $iMIB;
+        $hsMIBofShortname{&_strip($sAlias)} = $iMIB;
 	if ($mimename)
 	  {
           print STDERR " +   found mime: mib=$iMIB, mime=$sAlias\n" if $iDebug;
-	  $MIBtoMIME{$iMIB} = $sAlias;
+	  $hsMIMEofMIB{$iMIB} = $sAlias;
           # We've got the MIME name for this entry, don't look for
           # more until next entry:
           $mimename = 0;
@@ -967,7 +961,7 @@ while (1)
     next unless $as[0] ne '';
     next unless defined $as[1];
     next unless $as[1] ne '';
-    my $iMIB = $SHORTtoMIB{&_strip($as[0])} || '';
+    my $iMIB = $hsMIBofShortname{&_strip($as[0])} || '';
     unless ($iMIB ne '')
       {
       print STDERR " --- can not find IANA entry for equal-sign directive $as[0]\n";
@@ -977,7 +971,7 @@ while (1)
       {
       my $sStrip = &_strip($s);
       # print STDERR " +     $sStrip --> $iMIB\n";
-      $SHORTtoMIB{$sStrip} = $iMIB;
+      $hsMIBofShortname{$sStrip} = $iMIB;
       } # foreach
     } # foreach
 
@@ -1014,11 +1008,11 @@ while (1)
           # $iDebug = 1;
           $iMIB = $sFakeMIB++;
           print STDERR " +   had to use a dummy mib ($iMIB) for U::Map8==$sMap8==\n" if $iDebug;
-          $LONGtoMIB{$sMap8} = $iMIB;
+          $hsMIBofLongname{$sMap8} = $iMIB;
           } # unless
         else
           {
-          $iMIB = $LONGtoMIB{$sFound};
+          $iMIB = $hsMIBofLongname{$sFound};
           print STDERR " +   found IANA name $sFound ($iMIB) for Map8 entry $sMap8\n" if $iDebug;
           }
         # $iDebug = ($iMIB =~ m!225[23]!);
@@ -1029,8 +1023,8 @@ while (1)
         foreach my $s ($sMap8, @as)
           {
           $s = &_strip($s);
-          print STDERR " +      map $s to $iMIB in SHORTtoMIB...\n" if $iDebug;
-          $SHORTtoMIB{$s} = $iMIB;
+          print STDERR " +      map $s to $iMIB in hsMIBofShortname...\n" if $iDebug;
+          $hsMIBofShortname{$s} = $iMIB;
           } # foreach
         # $iDebug = 0;
         } # while
@@ -1056,16 +1050,16 @@ while (1)
     my $sMapFile = "$MAP_Path/REGISTRY";
     if (open MAPS, $sMapFile)
       {
-      local $/;
-      undef $/;
+      local $/ = undef;
       my @asMAPS = split(/\n\s*\n/, <MAPS>);
+ UMAP_ENTRY:
       foreach my $sEntry (@asMAPS)
         {
         $iDebug = 0;
         # print STDERR " + working on Umap entry >>>>>$sEntry<<<<<...\n";
         my ($sName, $iMIB) = ('', '');
         # Get the value of the name field, and skip entries with no name:
-        next unless $sEntry =~ m!^name:\s+(\S+)!mi;
+        next UMAP_ENTRY unless $sEntry =~ m!^name:\s+(\S+)!mi;
         $sName = $1;
         # $iDebug = ($sName =~ m!apple!);
         print STDERR " +   UMAP sName is $sName\n" if $iDebug;
@@ -1080,7 +1074,7 @@ while (1)
           {
           # This entry does not have the MIB listed.  See if the name
           # of any of the aliases are known to our iana tables:
- ALIAS:
+ UMAP_ALIAS:
           foreach my $sAlias ($sName, @asAlias)
             {
             print STDERR " +     try alias $sAlias\n" if $iDebug;
@@ -1089,7 +1083,7 @@ while (1)
               {
               print STDERR " +       matched\n" if $iDebug;
               $iMIB = $iMIBtry;
-              last ALIAS;
+              last UMAP_ALIAS;
               } # if
             } # foreach
           # If nothing matched, create a dummy mib:
@@ -1103,16 +1097,14 @@ while (1)
         # $iDebug = ($iMIB eq '17');
         print STDERR " +   UMAP mib is $iMIB\n" if $iDebug;
         $MIBtoUMAP{$iMIB} = $sName;
-        # Set the long IANA name, IF it is empty so far:
-        $MIBtoLONG{$iMIB} ||= $sName;
-        $LONGtoMIB{$sName} ||= $iMIB;
-        $SHORTtoMIB{&_strip($sName)} ||= $iMIB;
+        $hsMIBofLongname{$sName} ||= $iMIB;
+        $hsMIBofShortname{&_strip($sName)} ||= $iMIB;
         foreach my $sAlias (@asAlias)
           {
           print STDERR " +   UMAP alias $sAlias\n" if $iDebug;
-          $SHORTtoMIB{&_strip($sAlias)} = $iMIB;
-          } # while
-        } # foreach
+          $hsMIBofShortname{&_strip($sAlias)} = $iMIB;
+          } # foreach $sAlias
+        } # foreach UMAP_ENTRY
       close MAPS;
       # print STDERR "\n + MIBtoUMAP{dummymib029} == $MIBtoUMAP{$sDummy .'029'}\n\n";
       } # if open
@@ -1175,7 +1167,7 @@ UMU8_NAME:
 
   print STDERR " + the following IANA names do *not* have entries in the Map8 table:\n";
   my %hiTried = ();
-  foreach my $sIANA (sort values %MIBtoLONG)
+  foreach my $sIANA (sort values %hsLongnameOfMIB)
     {
     next if $hiTried{$sIANA};
     print "$sIANA\n" unless defined &map8_charset_name($sIANA);
@@ -1202,10 +1194,10 @@ UMU8_NAME:
   last INFINITE;
 
   # debugging: huge dump:
-  # &_dump_hash('MIBtoLONG', \%MIBtoLONG);
-  # &_dump_hash('LONGtoMIB', \%LONGtoMIB);
-  # &_dump_hash('SHORTtoMIB', \%SHORTtoMIB);
-  foreach (keys %SHORTtoMIB)
+  # &_dump_hash('hsLongnameOfMIB', \%hsLongnameOfMIB);
+  # &_dump_hash('hsMIBofLongname', \%hsMIBofLongname);
+  # &_dump_hash('hsMIBofShortname', \%hsMIBofShortname);
+  foreach (keys %hsMIBofShortname)
     {
     print STDERR " + _short_to_long($_) == ", &_short_to_long($_) || 'undef', "\n";
     } # foreach
@@ -1308,7 +1300,7 @@ sub _init_data
 ===================================================================
 CHARACTER SETS
 
-(last updated 2004-02-06)
+(last updated 28 January 2005)
 
 These are the official names for character sets that may be used in
 the Internet and may be referred to in Internet documentation.  These
@@ -1342,13 +1334,17 @@ intended for vendor specific coded character sets.
 	2000-2999	Vendor
 
 The aliases that start with "cs" have been added for use with the
-Printer MIB (see RFC 1759) and contain the standard numbers along with
-suggestive names in order to facilitate applications that want to
-display the names in user interfaces.  The "cs" stands for character
-set and is provided for applications that need a lower case first
-letter but want to use mixed case thereafter that cannot contain any
-special characters, such as underbar ("_") and dash ("-").  If the
-character set is from an ISO standard, its cs alias is the ISO
+IANA-CHARSET-MIB as originally defined in RFC3808, and as currently
+maintained by IANA at http://www/iana.org/assignments/ianacharset-mib.
+Note that the ianacharset-mib needs to be kept in sync with this
+registry.  These aliases that start with "cs" contain the standard 
+numbers along with suggestive names in order to facilitate applications 
+that want to display the names in user interfaces.  The "cs" stands 
+for character set and is provided for applications that need a lower 
+case first letter but want to use mixed case thereafter that cannot 
+contain any special characters, such as underbar ("_") and dash ("-").  
+
+If the character set is from an ISO standard, its cs alias is the ISO
 standard number or name.  If the character set is not from an ISO
 standard, but is registered with ISO (IPSJ/ITSCJ is the current ISO
 Registration Authority), the ISO Registry number is specified as
@@ -3174,3 +3170,4 @@ EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
 1;
 
 __END__
+
